import zxcvbn from 'zxcvbn';

//

var script = {
  name: 'DHKPasswordInput',
  props: {
    /**
    * Input and label-for id.
    * Default is 'input-password'
    * @type {String}
    */
    id: {
      type: String,
      default: 'input-password'
    },
    /**
    * Input type.
    * Default is password.
    * @type {String}
    */
    type: {
      type: String,
      default: 'password'
    },
    /**
    * Input placeholder.
    * Default is 'Enter your password'.
    * @type {String}
    */
    placeholder: {
      type: String,
      default: 'Enter your password'
    },
    /**
    * Input value.
    * @type {String}
    */
    value: {
      type: String
    },
    /**
    * Input field required flag.
    * Default is false.
    * @type {Boolean}
    */
    required: {
      type: Boolean,
      default: false
    },
    /**
    * Text displayed in the label.
    * Default is 'Password'.
    * @type {String}
    */
    labelText: {
      type: String,
      default: 'Password'
    },
    /**
    * CSS Classname for overall container.
    * Default is 'dhk-password-input'.
    * @type {String}
    */
    inputGroupClass: {
      type: String,
      default: 'dhk-password-input'
    },
    /**
    * CSS Classname for wrapper around the
    * label and password strength indicator.
    * Default is 'dhk-password-above-input'.
    * @type {String}
    */
    aboveInputClass: {
      type: String,
      default: 'dhk-password-above-input'
    },
    /**
    * CSS Classname for the label element.
    * Default is 'dhk-input-label'.
    * @type {String}
    */
    labelClass: {
      type: String,
      default: 'dhk-input-label'
    },
    /**
    * CSS Classname for the input element.
    * Default is 'dhk-input'.
    * @type {String}
    */
    inputClass: {
      type: String,
      default: 'dhk-input'
    },
    /**
    * CSS Classname for password strength indicator container.
    * Default is 'dhk-password-strength-container'.
    * @type {String}
    */
    passwordStrengthClass: {
      type: String,
      default: 'dhk-password-strength-container'
    },
    /**
    * CSS Classname for password strength indicator
    * inner div element (this div displays the color).
    * Default is 'dhk-password-strength-inner'.
    * @type {String}
    */
    passwordStrengthInnerClass: {
      type: String,
      default: 'dhk-password-strength-inner'
    }
  },
  data: function data () {
    return {
      password: '',
      score: 0
    }
  },
  computed: {
    /**
    * Generates the width of the scorebar.
    * @return {String} Width of scorebar in percentage.
    */
    getWidthByScore: function getWidthByScore () {
      return this.score * 25 + '%'
    },

    /**
    * Generates the correct classname to display the right color for each score.
    * @return {String} Classname for backgroundcolor.
    */
    getScoreColorClass: function getScoreColorClass () {
      var classPrefix = 'dhk-score-color-';
      var classSuffix = (this.score === 1) ? 'dark-red' : (this.score === 2) ? 'red' : (this.score === 3) ? 'orange' : (this.score === 4) ? 'green' : 'blank';
      return classPrefix + classSuffix
    }
  },
  methods: {
    /**
    * Calculates the score using zxcvbn and emits the score, user input.
    * Also emits the feedback if there is any.
    */
    calculateScore: function calculateScore() {
      var calculation = zxcvbn(this.password);
      this.score = calculation.score;

      this.$emit('score', calculation.score);
      this.$emit('inputChange', this.password);

      if (calculation.feedback.warning || calculation.feedback.suggestions.length) {
        this.$emit('feedback', calculation.feedback);
      }
    }
  }
};

/* script */
            var __vue_script__ = script;
            
/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", { class: _vm.inputGroupClass }, [
    _c("div", { class: _vm.aboveInputClass }, [
      _c("label", { class: _vm.labelClass, attrs: { for: _vm.id } }, [
        _vm._v(_vm._s(_vm.labelText))
      ]),
      _vm._v(" "),
      _c("div", { class: _vm.passwordStrengthClass }, [
        _c("div", {
          class: [_vm.passwordStrengthInnerClass, _vm.getScoreColorClass],
          style: { width: _vm.getWidthByScore }
        })
      ])
    ]),
    _vm._v(" "),
    _vm.type === "checkbox"
      ? _c("input", {
          directives: [
            {
              name: "model",
              rawName: "v-model",
              value: _vm.password,
              expression: "password"
            }
          ],
          class: _vm.inputClass,
          attrs: {
            id: _vm.id,
            placeholder: _vm.placeholder,
            required: _vm.required,
            type: "checkbox"
          },
          domProps: {
            value: _vm.value,
            checked: Array.isArray(_vm.password)
              ? _vm._i(_vm.password, _vm.value) > -1
              : _vm.password
          },
          on: {
            input: _vm.calculateScore,
            change: function($event) {
              var $$a = _vm.password,
                $$el = $event.target,
                $$c = $$el.checked ? true : false;
              if (Array.isArray($$a)) {
                var $$v = _vm.value,
                  $$i = _vm._i($$a, $$v);
                if ($$el.checked) {
                  $$i < 0 && (_vm.password = $$a.concat([$$v]));
                } else {
                  $$i > -1 &&
                    (_vm.password = $$a
                      .slice(0, $$i)
                      .concat($$a.slice($$i + 1)));
                }
              } else {
                _vm.password = $$c;
              }
            }
          }
        })
      : _vm.type === "radio"
        ? _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.password,
                expression: "password"
              }
            ],
            class: _vm.inputClass,
            attrs: {
              id: _vm.id,
              placeholder: _vm.placeholder,
              required: _vm.required,
              type: "radio"
            },
            domProps: {
              value: _vm.value,
              checked: _vm._q(_vm.password, _vm.value)
            },
            on: {
              input: _vm.calculateScore,
              change: function($event) {
                _vm.password = _vm.value;
              }
            }
          })
        : _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.password,
                expression: "password"
              }
            ],
            class: _vm.inputClass,
            attrs: {
              id: _vm.id,
              placeholder: _vm.placeholder,
              required: _vm.required,
              type: _vm.type
            },
            domProps: { value: _vm.value, value: _vm.password },
            on: {
              input: [
                function($event) {
                  if ($event.target.composing) {
                    return
                  }
                  _vm.password = $event.target.value;
                },
                _vm.calculateScore
              ]
            }
          })
  ])
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  var __vue_inject_styles__ = function (inject) {
    if (!inject) { return }
    inject("data-v-6f9178b2_0", { source: "\n.dhk-password-input[data-v-6f9178b2] {\n  min-width: 250px;\n  max-width: 400px;\n}\nlabel.dhk-input-label[data-v-6f9178b2] {\n  display: inline-block;\n  margin-left: 3px;\n  font-size: 18px;\n  line-height: 0.78;\n  color: #11162a;\n}\ninput.dhk-input[data-v-6f9178b2] {\n  display: block;\n  position: relative;\n  margin-top: 8px;\n  padding: 10px 10px;\n  width: 100%;\n  font-size: 14px;\n  color: #11162a;\n  border-radius: 2px;\n  outline: none;\n  border: solid 1px rgba(17, 22, 42, 0.16);\n  box-shadow: inset 0 1px 2px 0 rgba(17, 22, 42, 0.04);\n  box-sizing: border-box;\n}\n.dhk-password-above-input[data-v-6f9178b2] {\n  position: relative;\n}\n.dhk-password-strength-container[data-v-6f9178b2] {\n  position: absolute;\n  top: 50%;\n  right: 3px;\n  transform: translateY(-50%);\n  width: 88px;\n  height: 4px;\n  background-color: #e3e6e9;\n  border-radius: 4px;\n}\n.dhk-password-strength-inner[data-v-6f9178b2] {\n  height: 4px;\n  border-radius: 4px;\n  transition: all .5s ease-in-out;\n}\n.dhk-score-color-dark-red[data-v-6f9178b2] {\n  background-color: #9e0000;\n}\n.dhk-score-color-red[data-v-6f9178b2] {\n  background-color: #ff5c58;\n}\n.dhk-score-color-orange[data-v-6f9178b2] {\n  background-color: #f79627\n}\n.dhk-score-color-green[data-v-6f9178b2] {\n  background-color: #50ec99;\n}\n", map: {"version":3,"sources":["/Users/bramhoningh/Documents/projects/vue-password-strength/src/components/VuePasswordStrength.vue"],"names":[],"mappings":";AAwLA;EACA,iBAAA;EACA,iBAAA;CACA;AAEA;EACA,sBAAA;EACA,iBAAA;EACA,gBAAA;EACA,kBAAA;EACA,eAAA;CACA;AAEA;EACA,eAAA;EACA,mBAAA;EACA,gBAAA;EACA,mBAAA;EACA,YAAA;EACA,gBAAA;EACA,eAAA;EACA,mBAAA;EACA,cAAA;EACA,yCAAA;EACA,qDAAA;EACA,uBAAA;CACA;AAEA;EACA,mBAAA;CACA;AAEA;EACA,mBAAA;EACA,SAAA;EACA,WAAA;EACA,4BAAA;EACA,YAAA;EACA,YAAA;EACA,0BAAA;EACA,mBAAA;CACA;AAEA;EACA,YAAA;EACA,mBAAA;EACA,gCAAA;CACA;AAEA;EACA,0BAAA;CACA;AAEA;EACA,0BAAA;CACA;AAEA;EACA,yBAAA;CACA;AAEA;EACA,0BAAA;CACA","file":"VuePasswordStrength.vue","sourcesContent":["<template>\n<div :class=\"inputGroupClass\">\n  <div :class=\"aboveInputClass\">\n    <label :class=\"labelClass\" :for=\"id\">{{labelText}}</label>\n    <div :class=\"passwordStrengthClass\">\n      <div :class=\"[passwordStrengthInnerClass, getScoreColorClass]\"\n        :style=\"{'width': getWidthByScore}\"\n      ></div>\n    </div>\n  </div>\n  <input\n    :id=\"id\"\n    :class=\"inputClass\"\n    :type=\"type\"\n    :placeholder=\"placeholder\"\n    :value=\"value\"\n    :required=\"required\"\n    v-model=\"password\"\n    @input=\"calculateScore\"\n  />\n</div>\n</template>\n\n<script>\nimport zxcvbn from 'zxcvbn'\n\nexport default {\n  name: 'DHKPasswordInput',\n  props: {\n    /**\n    * Input and label-for id.\n    * Default is 'input-password'\n    * @type {String}\n    */\n    id: {\n      type: String,\n      default: 'input-password'\n    },\n    /**\n    * Input type.\n    * Default is password.\n    * @type {String}\n    */\n    type: {\n      type: String,\n      default: 'password'\n    },\n    /**\n    * Input placeholder.\n    * Default is 'Enter your password'.\n    * @type {String}\n    */\n    placeholder: {\n      type: String,\n      default: 'Enter your password'\n    },\n    /**\n    * Input value.\n    * @type {String}\n    */\n    value: {\n      type: String\n    },\n    /**\n    * Input field required flag.\n    * Default is false.\n    * @type {Boolean}\n    */\n    required: {\n      type: Boolean,\n      default: false\n    },\n    /**\n    * Text displayed in the label.\n    * Default is 'Password'.\n    * @type {String}\n    */\n    labelText: {\n      type: String,\n      default: 'Password'\n    },\n    /**\n    * CSS Classname for overall container.\n    * Default is 'dhk-password-input'.\n    * @type {String}\n    */\n    inputGroupClass: {\n      type: String,\n      default: 'dhk-password-input'\n    },\n    /**\n    * CSS Classname for wrapper around the\n    * label and password strength indicator.\n    * Default is 'dhk-password-above-input'.\n    * @type {String}\n    */\n    aboveInputClass: {\n      type: String,\n      default: 'dhk-password-above-input'\n    },\n    /**\n    * CSS Classname for the label element.\n    * Default is 'dhk-input-label'.\n    * @type {String}\n    */\n    labelClass: {\n      type: String,\n      default: 'dhk-input-label'\n    },\n    /**\n    * CSS Classname for the input element.\n    * Default is 'dhk-input'.\n    * @type {String}\n    */\n    inputClass: {\n      type: String,\n      default: 'dhk-input'\n    },\n    /**\n    * CSS Classname for password strength indicator container.\n    * Default is 'dhk-password-strength-container'.\n    * @type {String}\n    */\n    passwordStrengthClass: {\n      type: String,\n      default: 'dhk-password-strength-container'\n    },\n    /**\n    * CSS Classname for password strength indicator\n    * inner div element (this div displays the color).\n    * Default is 'dhk-password-strength-inner'.\n    * @type {String}\n    */\n    passwordStrengthInnerClass: {\n      type: String,\n      default: 'dhk-password-strength-inner'\n    }\n  },\n  data () {\n    return {\n      password: '',\n      score: 0\n    }\n  },\n  computed: {\n    /**\n    * Generates the width of the scorebar.\n    * @return {String} Width of scorebar in percentage.\n    */\n    getWidthByScore () {\n      return this.score * 25 + '%'\n    },\n\n    /**\n    * Generates the correct classname to display the right color for each score.\n    * @return {String} Classname for backgroundcolor.\n    */\n    getScoreColorClass () {\n      let classPrefix = 'dhk-score-color-'\n      let classSuffix = (this.score === 1) ? 'dark-red' : (this.score === 2) ? 'red' : (this.score === 3) ? 'orange' : (this.score === 4) ? 'green' : 'blank'\n      return classPrefix + classSuffix\n    }\n  },\n  methods: {\n    /**\n    * Calculates the score using zxcvbn and emits the score, user input.\n    * Also emits the feedback if there is any.\n    */\n    calculateScore() {\n      let calculation = zxcvbn(this.password)\n      this.score = calculation.score\n\n      this.$emit('score', calculation.score)\n      this.$emit('inputChange', this.password)\n\n      if (calculation.feedback.warning || calculation.feedback.suggestions.length) {\n        this.$emit('feedback', calculation.feedback)\n      }\n    }\n  }\n}\n</script>\n\n<style lang=\"css\" scoped>\n.dhk-password-input {\n  min-width: 250px;\n  max-width: 400px;\n}\n\nlabel.dhk-input-label {\n  display: inline-block;\n  margin-left: 3px;\n  font-size: 18px;\n  line-height: 0.78;\n  color: #11162a;\n}\n\ninput.dhk-input {\n  display: block;\n  position: relative;\n  margin-top: 8px;\n  padding: 10px 10px;\n  width: 100%;\n  font-size: 14px;\n  color: #11162a;\n  border-radius: 2px;\n  outline: none;\n  border: solid 1px rgba(17, 22, 42, 0.16);\n  box-shadow: inset 0 1px 2px 0 rgba(17, 22, 42, 0.04);\n  box-sizing: border-box;\n}\n\n.dhk-password-above-input {\n  position: relative;\n}\n\n.dhk-password-strength-container {\n  position: absolute;\n  top: 50%;\n  right: 3px;\n  transform: translateY(-50%);\n  width: 88px;\n  height: 4px;\n  background-color: #e3e6e9;\n  border-radius: 4px;\n}\n\n.dhk-password-strength-inner {\n  height: 4px;\n  border-radius: 4px;\n  transition: all .5s ease-in-out;\n}\n\n.dhk-score-color-dark-red {\n  background-color: #9e0000;\n}\n\n.dhk-score-color-red {\n  background-color: #ff5c58;\n}\n\n.dhk-score-color-orange {\n  background-color: #f79627\n}\n\n.dhk-score-color-green {\n  background-color: #50ec99;\n}\n</style>\n\n"]}, media: undefined });

  };
  /* scoped */
  var __vue_scope_id__ = "data-v-6f9178b2";
  /* module identifier */
  var __vue_module_identifier__ = undefined;
  /* functional template */
  var __vue_is_functional_template__ = false;
  /* component normalizer */
  function __vue_normalize__(
    template, style, script$$1,
    scope, functional, moduleIdentifier,
    createInjector, createInjectorSSR
  ) {
    var component = (typeof script$$1 === 'function' ? script$$1.options : script$$1) || {};

    // For security concerns, we use only base name in production mode.
    component.__file = "/Users/bramhoningh/Documents/projects/vue-password-strength/src/components/VuePasswordStrength.vue";

    if (!component.render) {
      component.render = template.render;
      component.staticRenderFns = template.staticRenderFns;
      component._compiled = true;

      if (functional) { component.functional = true; }
    }

    component._scopeId = scope;

    {
      var hook;
      if (style) {
        hook = function(context) {
          style.call(this, createInjector(context));
        };
      }

      if (hook !== undefined) {
        if (component.functional) {
          // register for functional component in vue file
          var originalRender = component.render;
          component.render = function renderWithStyleInjection(h, context) {
            hook.call(context);
            return originalRender(h, context)
          };
        } else {
          // inject component registration as beforeCreate hook
          var existing = component.beforeCreate;
          component.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
      }
    }

    return component
  }
  /* style inject */
  function __vue_create_injector__() {
    var head = document.head || document.getElementsByTagName('head')[0];
    var styles = __vue_create_injector__.styles || (__vue_create_injector__.styles = {});
    var isOldIE =
      typeof navigator !== 'undefined' &&
      /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());

    return function addStyle(id, css) {
      if (document.querySelector('style[data-vue-ssr-id~="' + id + '"]')) { return } // SSR styles are present.

      var group = isOldIE ? css.media || 'default' : id;
      var style = styles[group] || (styles[group] = { ids: [], parts: [], element: undefined });

      if (!style.ids.includes(id)) {
        var code = css.source;
        var index = style.ids.length;

        style.ids.push(id);

        if (isOldIE) {
          style.element = style.element || document.querySelector('style[data-group=' + group + ']');
        }

        if (!style.element) {
          var el = style.element = document.createElement('style');
          el.type = 'text/css';

          if (css.media) { el.setAttribute('media', css.media); }
          if (isOldIE) {
            el.setAttribute('data-group', group);
            el.setAttribute('data-next-index', '0');
          }

          head.appendChild(el);
        }

        if (isOldIE) {
          index = parseInt(style.element.getAttribute('data-next-index'));
          style.element.setAttribute('data-next-index', index + 1);
        }

        if (style.element.styleSheet) {
          style.parts.push(code);
          style.element.styleSheet.cssText = style.parts
            .filter(Boolean)
            .join('\n');
        } else {
          var textNode = document.createTextNode(code);
          var nodes = style.element.childNodes;
          if (nodes[index]) { style.element.removeChild(nodes[index]); }
          if (nodes.length) { style.element.insertBefore(textNode, nodes[index]); }
          else { style.element.appendChild(textNode); }
        }
      }
    }
  }
  /* style inject SSR */
  

  
  var component = __vue_normalize__(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    __vue_create_injector__,
    undefined
  );

// Import vue component

// Declare install function executed by Vue.use()
function install(Vue) {
    if (install.installed) { return; }
    install.installed = true;
    Vue.component('VuePasswordStrength', component);
}

// Create module definition for Vue.use()
var plugin = {
    install: install,
};

// Auto-install when vue is found (eg. in browser via <script> tag)
var GlobalVue = null;
if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
} else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
}
if (GlobalVue) {
    GlobalVue.use(plugin);
}

export default component;
export { install };
